function ModSpecEff1 = modscheme(SNR1,bitshz,diff_coherent,Tolerance)
%This function returns the modulation scheme that can be used for each
%signal noise ratio given in SNR1
% SNR, vector or matrix with Signal to Noise Ratio values in dB
% bitshz vector with a list of the modulation schemes to use in bits/Hz
% for example to use BPSK, QPSK, 8QAM, 16QAM:
% bitshz = [1 2 3 4];
% diff_coherent = 0 , coherent
% diff_coherent = 1, differential modulation, This is currently not supported
%
% Tolerance in dB, this is the safety marin to use when choosing modulation.
% A tolerance of 0dB will give a BER of 1e-4

%Copyright Eric Lawrey July 2000
%version 1.0

ModSpecEff1 = zeros(size(SNR1));
if diff_coherent == 0
%SNR Thresholds in dB, for each modulation scheme (coherent) to obtain BER < 1e-4 
ModThreshList = [8.38 11.78 15.3 18.19 21.5 24.3 27.5 30.35 34.5 39 43.5 48];
ModEffList = [1:12];
ModThresh = ModThreshList(sort(bitshz));
ModEff = sort(bitshz);
else
   error('differential modulation not currently supported')
end


%Tolerance = 1;	%Tolerance in dB, this is the safety marin to use

%Set the modulation schemes assume no delay
for l = length(ModThresh):-1:1
      if l == length(ModThresh)
         UppThres = Inf;
      else
         UppThres = ModThresh(l+1);
      end
      LowThres = ModThresh(l);
      ind1 = find(((SNR1-Tolerance)>=LowThres)&((SNR1-Tolerance)<UppThres));
      ModSpecEff1(ind1) = ones(size(ind1))*ModEff(l);
      ind = find(isnan(SNR1));
      ModSpecEff1(ind) = ones(size(ind))*NaN;
end
