function h = plotmodelobj(objs,colourscale)
%PLOTMODELOBJ Plots objects as fills from the radio model data structure
% PLOTMODELOBJ(OBJS,colourscale)
% objs should have the following fields
%vertices - 	complex coordinate of the vertex points of the object
%reflection - reflectiveness of the object (fraction of incident power reflected)
%attenuation - power attenuation of a ray passing through the object in dB per metre
%roughness - 	roughness of the surface of the object. This is the standard deviation
%				(in radians) of the reflected (and transmitted) ray power. for example
%				roughness of 0.01 is a highly polished surface, a roughness of >10
%				would simulate light reflection off white paper, i.e. the diffuse reflection
%				is a cell array, with each cell containing
% The colour of each object is plotted with based on the attenuation of the object. The larger
% the attenuation the darker the object is. 100 dB/m - black 0 db/m - white
% The edge colour of the objects is based on the reflection coefficient. 1 (mirror) - white
% 0 black surface - black
% colourscale : Scales the colour drawn for the objects. Colourscale = 2, double brightness, etc
% default is 1.
% H = PLOTOBJS(....) this plots the objects, and returns
% the handles to the fill objects

% Eric Lawrey 23/11/99
%Version 1.1
%3/8/00 version 1.1
%Added colourscaling
if nargin < 2
   colourscale = 1;
end

h2 = [];
%Plot each object separately
for k = 1:size(objs,2)
   c = ones(1,3)*clip(((1-objs(k).attenuation/100)*colourscale),0,1);
   ht = fill(real(objs(k).vertices),imag(objs(k).vertices),c);
   e = ones(1,3)*clip((1-objs(k).reflection)*sqrt(colourscale),0,1);
   set(ht, 'EdgeColor',e);
   hold on
   h2 = [h2 ht];	%collect the graphics object handles of the fills
end
hold off

if nargout == 1
   h = h2;
end

function y = clip(x,low,high)
%CLIP clips the input signal to a lower and upper limit
%y = clip(x,low,high)
%Clips the signal x to a lower limit of 'low' and an upper
%limit of 'high'
y = x;
%Clip on the lower side
ind = find(x<low);
y(ind) = ones(size(ind))*low;

%clip high signals
ind = find(x>high);
y(ind) = ones(size(ind))*high;