function plotresult(x,y,zt,objs,filename,horzsize,vertsize,coloraxis,colorbarflag,colourmap)
%This function plots 2D signal power as a surface plot. 
%It also overlays the object model used in the simulations and adds a colorbar 
%to the side of the plot.
%plotresult(x,y,zt,objs,filename,horzsize,vertsize,coloraxis,colorbarflag,colourmap)
% x, y: Vectors with the x, and y scale
% zt: 2D matrix with the signal power to plot
% objs: Object model to overlay on the plot. See genmodel for more details
% horzsize, vertsize: size of the plot in pixels
% coloraxis: scale used to set the color of the plot, see caxis
% colorbarflag : 1 = add a colorbar showing the colour scaling, 0 = no bar (Default = 0)
% colourmap : Colourmap to use for the plot (Default = gray)

%Copyright Eric Lawrey August 2000
%Version 1.2
% Added the option of setting the colourmap

if nargin < 9
   colorbarflag = 0;
end

if nargin < 10
   colourmap = gray;
end

pcolor(x,y,zt); shading interp; caxis(coloraxis); colormap(colourmap);
hold on
plotmodelobj(objs);
hold off
axis off
a = get(gcf,'children');
set(a,'position',[0 0 1 1])
setplotsize(horzsize,vertsize);

%Scale the the plot to fit the colorbar in. Make the font size large on the scale
if colorbarflag == 1
   c = colorbar('vert');
   g = get(gcf,'children');
   set(g(1),'position',[0 0 0.87 1])
   set(c,'fontweight','bold')
   set(c,'position', [0.875 0.03 0.04 0.94])
   set(c,'fontsize',18)
   set(gcf,'color',[0.6 0.6 1])
end

savefig(filename,'jpg');
