%This script searches for a good equation which will give pilot reference
%symbols which are flat spectrally (i.e. not a frequency sweep), and also
%have a low crest factor.
%The phase formula is tested over a range of number of carriers to verify
%that it works.
NcarriersList = [intlogspace(16,256,10)];	%Number of carriers to test
ifft_size_list = [2.^(ceil(log2(NcarriersList+1)+1))];
guard_period = 0;
fast_mode = 0;
real_complex = 'complex';

%Equation coefficients.
S = [0 0 0];
Index = 2;
N = 500;

CoeffList = linspace(0,3,N);
SeqData = repmat(S',1,N);
Nc = length(NcarriersList);
Flat = zeros(N,Nc);
CF2 = zeros(N,Nc);
for Ncarr = 1:length(NcarriersList)
   Ncarriers = NcarriersList(Ncarr);
   ifft_size = ifft_size_list(Ncarr);
   SeqData(Index,:) = CoeffList;
      
      %=========================================
      %	Measure the spectral flatness and CF
      %=========================================
      fast_mode = 0;
      K = repmat((1:Ncarriers)',1,size(SeqData,2));
      rows = Ncarriers;
      S = SeqData;
      Phase = zeros(size(K));
      for si = 1:size(S,1)
         Phase = Phase+repmat(S(si,:),rows,1).*K.^(size(S,1)-si+1);
      end
      Mag = ones(size(K));
      [x,y] = pol2cart(Phase,Mag);
      data_vector = x+i*y;
      data_carriers = mkcarriers(Ncarriers,ifft_size,real_complex);
      outsymbol = ofdmmod(data_vector,data_carriers, ifft_size, guard_period,... 
         real_complex, fast_mode);
      CF2(:,Ncarr) = (max((abs(outsymbol).^2))./(mean(abs(outsymbol).^2)))';
      
      Flat(:,Ncarr) = (specflat(outsymbol, data_carriers, ifft_size))';
      
      %=========================================
	   disp(['Ncarriers : ' num2str(Ncarriers)])
end
figure(1)
plot(CoeffList,10*log10(Flat))
xlabel('Phase Equation Coeff. A, Ph = A*X^2')
ylabel('Time Spectral Flatness (dB)');
setplotstyle(0.5)
savefig('s0056_flatness');
figure(2)
plot(CoeffList,10*log10(CF2))
xlabel('Phase Equation Coeff. A, Ph = A*X^2')
ylabel('Crest Factor (dB)');
setplotstyle(0.5)
savefig('s0056_CF');